@@ -12,6 +12,7 @@
 
 #include <stdlib.h>
 #include "itclInt.h"
+#include "itclUuid.h"
 
 static Tcl_NamespaceDeleteProc FreeItclObjectInfo;
 static Tcl_ObjCmdProc ItclSetHullWindowName;
@@ -160,6 +161,11 @@ RootCallProc(
  * ------------------------------------------------------------------------
  */
 
+#ifndef STRINGIFY
+#  define STRINGIFY(x) STRINGIFY1(x)
+#  define STRINGIFY1(x) #x
+#endif
+
 static int
 Initialize (
     Tcl_Interp *interp)
@@ -175,8 +181,9 @@ Initialize (
     Tcl_Class tclCls;
     Tcl_Object clazzObjectPtr, root;
     Tcl_Obj *objPtr, *resPtr;
+    Tcl_CmdInfo info;
 
-    if (Tcl_InitStubs(interp, "8.6", 0) == NULL) {
+    if (Tcl_InitStubs(interp, "8.6-", 0) == NULL) {
         return TCL_ERROR;
     }
 
@@ -400,6 +407,61 @@ Initialize (
      *  Package is now loaded.
      */
 
+    if (Tcl_GetCommandInfo(interp, "::tcl::build-info", &info)) {
+	Tcl_CreateObjCommand(interp, "::itcl::build-info",
+		info.objProc, (void *)(PACKAGE_VERSION "+" STRINGIFY(ITCL_VERSION_UUID)
+#if defined(__clang__) && defined(__clang_major__)
+	    ".clang-" STRINGIFY(__clang_major__)
+#if __clang_minor__ < 10
+	    "0"
+#endif
+	    STRINGIFY(__clang_minor__)
+#endif
+#if defined(__cplusplus) && !defined(__OBJC__)
+	    ".cplusplus"
+#endif
+#ifndef NDEBUG
+	    ".debug"
+#endif
+#if !defined(__clang__) && !defined(__INTEL_COMPILER) && defined(__GNUC__)
+	    ".gcc-" STRINGIFY(__GNUC__)
+#if __GNUC_MINOR__ < 10
+	    "0"
+#endif
+	    STRINGIFY(__GNUC_MINOR__)
+#endif
+#ifdef __INTEL_COMPILER
+	    ".icc-" STRINGIFY(__INTEL_COMPILER)
+#endif
+#ifdef TCL_MEM_DEBUG
+	    ".memdebug"
+#endif
+#if defined(_MSC_VER)
+	    ".msvc-" STRINGIFY(_MSC_VER)
+#endif
+#ifdef USE_NMAKE
+	    ".nmake"
+#endif
+#ifndef TCL_CFG_OPTIMIZED
+	    ".no-optimize"
+#endif
+#ifdef __OBJC__
+	    ".objective-c"
+#if defined(__cplusplus)
+	    "plusplus"
+#endif
+#endif
+#ifdef TCL_CFG_PROFILED
+	    ".profile"
+#endif
+#ifdef PURIFY
+	    ".purify"
+#endif
+#ifdef STATIC_BUILD
+	    ".static"
+#endif
+		), NULL);
+    }
     Tcl_PkgProvideEx(interp, "Itcl", ITCL_PATCH_LEVEL, &itclStubs);
     return Tcl_PkgProvideEx(interp, "itcl", ITCL_PATCH_LEVEL, &itclStubs);
 }
@@ -465,16 +527,16 @@ Itcl_SafeInit (
  */
 static int
 ItclSetHullWindowName(
-    void *clientData,   /* infoPtr */
-    Tcl_Interp *interp,      /* current interpreter */
+    void *clientData,        /* infoPtr */
+    TCL_UNUSED(Tcl_Interp *),/* current interpreter */
     int objc,                /* number of arguments */
     Tcl_Obj *const objv[])   /* argument objects */
 {
     ItclObjectInfo *infoPtr;
 
     infoPtr = (ItclObjectInfo *)clientData;
-    if (infoPtr->currIoPtr != NULL) {
-        infoPtr->currIoPtr->hullWindowNamePtr = objv[1];
+    if ((infoPtr->currIoPtr != NULL) && (objc > 1)) {
+	infoPtr->currIoPtr->hullWindowNamePtr = objv[1];
 	Tcl_IncrRefCount(infoPtr->currIoPtr->hullWindowNamePtr);
     }
     return TCL_OK;
